// BasisForChoice.java - basis for choosing among equivalents.
// Copyright (c) 2000 by Reuters PLC and Wavo Company, Inc.
// $Id: BasisForChoice.java,v 1.8 2001/05/23 01:56:17 david Exp $

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.newsml.toolkit;


/**
 * Basis for choosing among equivalent news components or content items.
 *
 * <p>When a {@link NewsComponent} is an equivalents list (see {@link
 * NewsComponent#isEquivalentsList}) it may provide one or more hints
 * on how to select from the list.  This interface provides an XPath
 * to the relevant information (requiring, unfortunately, access to
 * the full DOM tree) together with ranking information.</p>
 *
 * <p>Note that the documentation does not specifically state that
 * basis for choice can apply to an equivalents list of {@link
 * NewsItem} or {@link NewsItemRef} members in a news component; use
 * with caution until the IPTC clarifies the rules.</p>
 *
 * @author Reuters PLC
 * @version 1.0
 */
public interface BasisForChoice
    extends BaseNode, IdNode
{

    /**
     * Get the XPath expression for choosing among the equivalents.
     *
     * The XPath is relative to each of the children of the {@link
     * NewsComponent} containing the basis for choice element.
     *
     * @return A string providing the XPath expression for choosing
     * among equivalent members.
     */
    public String getXPath ();


    /**
     * Rank this basis for choice.
     *
     * @return An integer ranking this basis for choice among the
     * others (a lower number indicates higher importance), or -1
     * if no explicit rank was provided.
     */
    public int getRank ();

}

// end of BasisForChoice.java
