// NewsItem.java - a top-level news item.
// Copyright (c) 2000 by Reuters PLC and Wavo Company, Inc.
// $Id: NewsItem.java,v 1.10 2001/05/23 01:56:17 david Exp $

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.newsml.toolkit;


/**
 * A managed set of news information.
 *
 * <p>A news item is a branch in the NewsML content tree that attaches
 * identification and management information to news objects; much of
 * the interesting information (such as headlines and subheadlines,
 * metadata, and the actual content) is available in or through the
 * root news component (see {@link #getRootNewsComponent}).</p>
 * 
 * <p>This interface currently omits the following information:</p>
 *
 * <ul>
 * <li>Incremental updates specified for the news item.</li>
 * </ul>
 *
 * @author Reuters PLC
 * @version 1.0
 */
public interface NewsItem
    extends BaseNode,CatalogNode, CommentNode, IdNode, LanguageNode,
    PrimaryNode
{

    /**
     * Get the identification labels.
     *
     * @return An object containing the identification labels
     * for this news item (not null).
     */
    public Identification getIdentification ();


    /**
     * Get the management information for the news item.
     *
     * The management information includes the type of the news item,
     * its status (including whether it's embargoed), when it was
     * created, and similar information.
     *
     * @return An object containing the management information for the
     * news item (not null).
     */
    public NewsManagement getNewsManagement ();


    /**
     * Get the root component of the news item.
     *
     * Return the root component of the news item.  The component
     * contains newslines, metadata, and other similar information,
     * and is the beginning of the path down the NewsML tree to the
     * actual content.  If this method returns a non-null value,
     * {@link #getRootTopicSet} must return null, and vice-versa.
     *
     * @return The root news component, or null if none was specified.
     */
    public NewsComponent getRootNewsComponent ();


    /**
     * Get the root topic set of the news item.
     *
     * If the topic set is present, it is actually the payload of
     * this newsitem, rather than simply metadata describing the
     * payload.  If this method returns a non-null value,
     * {@link #getRootNewsComponent} must return null, and vice-versa.
     *
     * @return The root topic set, or null if none was specified.
     */
    public TopicSet getRootTopicSet ();

}

// end of NewsItem.java
