// PropertyNode.java - interface for nodes with properties.
// Copyright (c) 2001 by Reuters PLC and Wavo Company, Inc.
// $Id: PropertyNode.java,v 1.10 2001/05/23 01:56:18 david Exp $

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.newsml.toolkit;


/**
 * Interface for nodes with properties.
 *
 * @author Reuters PLC
 * @version 1.0
 */
public interface PropertyNode
{

    /**
     * Count the properties.
     *
     * @return The number of property nodes.
     */
    public abstract int getPropertyCount ();


    /**
     * Get a generic property.
     *
     * @param index The index of the property, zero-based, in
     * sequential order.
     * @return The property, or null if none was present at the
     * specified index.
     */
    public abstract Property getProperty (int index);


    /**
     * Get all Property children in an array.
     *
     * @return A (possibly-empty) array of Property children.
     */
    public Property [] getProperty ();

}

// end of PropertyNode.java
