// RevisionId.java - revision information for a news item.
// Copyright (c) 2000 by Reuters PLC and Wavo Company, Inc.

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.newsml.toolkit;


/**
 * Revision information for a news item.
 *
 * <p>The RevisionId is part of the {@link NewsIdentifier} for a
 * {@link NewsItem}.  Each revision of a news item is identified by a
 * positive integer higher than that of the previous revision (if
 * any).</p>
 *
 * @author Reuters PLC
 * @version 1.0
 */
public interface RevisionId
    extends BaseNode, IdNode
{

    /**
     * Get the number of this revision of the news item.
     *
     * @return A positive, non-zero integer indicating the current
     * revision number, or -1 if the revision number was omitted
     * (in which case the document is not NewsML-conformant).
     */
    public int getValue ();


    /**
     * Get the number of the previous revision of the news item.
     *
     * @return A positive, non-zero integer indicating the previous
     * revision, 0 if this is the first revision, or -1 if the
     * previous revision number was omitted (in which case the
     * document is not NewsML-conformant).
     */
    public int getPreviousRevision ();


    /**
     * Get the update parameter for the revision information.
     *
     * The value of the parameter will be "U" if the news item
     * contains an Update element (not explicitly supported by this
     * library), "A" if the news item contains only updated 
     * {@link NewsManagement} information, or "N" otherwise.
     *
     * @return The update parameter as a string (not null).
     */
    public String getUpdate ();

}

// end of RevisionId.java
