// SubjectCode.java - an IPTC subject code.
// Copyright (c) 2000 by Reuters PLC and Wavo Company, Inc.
// $Id: SubjectCode.java,v 1.10 2001/05/23 01:56:18 david Exp $

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.newsml.toolkit;


/**
 * An IPTC subject code from the IPTC Information Interchange Model (IIM).
 *
 * <p>The subject code is part of the {@link DescriptiveMetadata} for
 * a {@link NewsComponent}.</p>
 *
 * <p>Although the NewsML documentation limits this property to IPTC
 * subject codes, the fact that the codes are formal names implies
 * that other vocabularies could be used; programmers should take care
 * using this interface until the IPTC clarifies the situation, since
 * providers may choose to take a liberal interpretation.</p>
 *
 * @author Reuters PLC
 * @version 1.0
 */
public interface SubjectCode
    extends AssignmentNode, BaseNode, IdNode
{

    /**
     * Count the items available in this subject code.
     *
     * @return The number of items available.
     * @see #getItem
     */
    public int getItemCount ();


    /**
     * Get an item from the subject code.
     *
     * <p>The item includes a single piece of Subject, SubjectMatter,
     * or Subject information together with zero or more
     * SubjectQualifiers.</p>
     *
     * @param index The index of the item, zero-based, numbered
     * sequentially.
     * @return The item, or null if none was provided at the specified
     * index.
     */
    public SubjectCodeItem getItem (int index);


    /**
     * Get all Item children in an array.
     *
     * @return A (possibly-empty) array of Item children.
     */
    public SubjectCodeItem [] getItem ();

}

// end of SubjectCode.java
