// TopicSet.java - a collection of metadata.
// Copyright (c) 2001 by Reuters PLC.
// $Id: TopicSet.java,v 1.11 2001/05/23 01:56:18 david Exp $

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.newsml.toolkit;


/**
 * A collection of metadata.
 *
 * @author Reuters PLC
 * @version 1.0
 */
public interface TopicSet
    extends CatalogNode, CommentNode, FormalName
{

    /**
     * Count the topic-set references.
     *
     * @return The number of topic-set references present.
     */
    public int getTopicSetRefCount ();


    /**
     * Get a reference to another topic set.
     *
     * @param index The index of the topic set reference, zero-based,
     * numbered sequentially in document order.
     * @return The reference, or null if none was provided at the
     * specified index.
     */
    public TopicSetRef getTopicSetRef (int index);


    /**
     * Get all TopicSetRef children in an array.
     *
     * @return A (possibly-empty) array of TopicSetRef children.
     */
    public TopicSetRef [] getTopicSetRef ();


    /**
     * Count the topics.
     *
     * @return The number of topics present.
     */
    public int getTopicCount ();


    /**
     * Get a topic in the topic set.
     *
     * @param index The index of the topic, zero-based, numbered
     * sequentially in document order.
     * @return The topic, or null if none was provided at the specified
     * index.
     */
    public Topic getTopic (int index);
    

    /**
     * Get all Topic children in an array.
     *
     * @return A (possibly-empty) array of Topic children.
     */
    public Topic [] getTopic ();


}

// end of TopicSet.java
