// TransmissionId.java - identifier for a NewsML document transmission.
// Copyright (c) 2000 by Reuters PLC and Wavo Company, Inc.
// $Id: TransmissionId.java,v 1.8 2001/05/23 01:56:18 david Exp $

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.newsml.toolkit;


/**
 * An identifier for a NewsML document transmission.
 *
 * <p>The transmission id is part of the {@link NewsEnvelope} for a
 * NewsML package.  It is unique among all transmissions from the same
 * publisher.</p>
 *
 * @author Reuters PLC
 * @version 1.0
 */
public interface TransmissionId
    extends BaseNode, IdNode
{

    /**
     * Get the value of the transmission id.
     *
     * @return A string representing the value (not null).
     */
    public String getValue ();


    /**
     * Get the repeat value for the transmission id.
     *
     * The format of the repeat value is unspecified, and may vary
     * from provider to provider.
     *
     * @return A string representing the repeat value, or null if none
     * was specified.
     */
    public String getRepeat ();

}

// end of TransmissionId.java
