// DOMContentItem.java - DOM implementation of ContentItem.
// Copyright (c) 2000 by Reuters PLC and Wavo Company, Inc.
// Copyright (c) 2001 by Reuters PLC
// $Id: DOMContentItem.java,v 1.12 2001/05/23 01:56:18 david Exp $

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.newsml.toolkit.dom;

import org.w3c.dom.Node;
import org.w3c.dom.NodeList;

import org.newsml.toolkit.Catalog;
import org.newsml.toolkit.Characteristics;
import org.newsml.toolkit.Comment;
import org.newsml.toolkit.ContentItem;
import org.newsml.toolkit.FormalName;
import org.newsml.toolkit.PrimaryNode;


/**
 * DOM implementation of ContentItem
 *
 * @author Reuters PLC
 * @version 1.0
 */
class DOMContentItem
    extends DOMPrimaryNode
    implements ContentItem
{

    /**
     * Constructor.
     *
     * @param element The DOM node representing the content item.
     */
    protected DOMContentItem (Node element, DOMNewsMLSession session)
    {
	super(element, session);
    }


    /**
     * @see ContentItem#getType()
     */
    public int getType ()
    {
	return PrimaryNode.CONTENT_ITEM;
    }


    /**
     * @see ContentItem#getMediaType()
     */
    public FormalName getMediaType ()
    {
	return getDOMFormalName("MediaType", 0);
    }


    /**
     * @see ContentItem#getFormat()
     */
    public FormalName getFormat ()
    {
	return getDOMFormalName("Format", 0);
    }


    /**
     * @see ContentItem#getMimeType()
     */
    public FormalName getMimeType ()
    {
	return getDOMFormalName("MimeType", 0);
    }


    /**
     * @see ContentItem#getNotation()
     */
    public FormalName getNotation ()
    {
	return getDOMFormalName("Notation", 0);
    }


    /**
     * @see ContentItem#getCharacteristics()
     */
    public Characteristics getCharacteristics ()
    {
	Node e = getDOMChild("Characteristics");
	return (e == null ? null : new DOMCharacteristics(e, session));
    }


    /**
     * @see ContentItem#getEncodingCount()
     */
    public int getEncodingCount ()
    {
	int n = 0;
	Node e = getDOMChild("Encoding");
	while (e != null) {
	    n++;
	    e = DOMUtils.find(e, "Encoding");
	}
	return n;
    }


    /**
     * @see ContentItem#getEncoding(int)
     */
    public String getEncoding (int index)
    {
	Node e = getDOMChild("Encoding");
	for (int i = 0; i < index; i++)
	    e = DOMUtils.find(e, "Encoding");
	return (e == null ? null : DOMUtils.getAttribute(e, "Notation"));
    }


    /**
     * @see ContentItem#getEncoding()
     */
    public String [] getEncoding ()
    {
	int len = getEncodingCount();
	String ret[] = new String[len];
	for (int i = 0; i < len; i++)
	    ret[i] = getEncoding(i);
	return ret;
    }


    /**
     * @see ContentItem#getDataContent()
     */
    public NodeList getDataContent ()
    {
	Node element = getDOMNode();
	Node content = DOMUtils.find(element, "DataContent");
	while (content == null) {
	    Node encoding = DOMUtils.find(element, "Encoding");
	    if (element == null)
		return null;
	    else
		element = encoding;
	    content = DOMUtils.find(element, "DataContent");
	}
	return content.getChildNodes();
    }


    /**
     * @see ContentItem#getDataText()
     */
    public String getDataText ()
    {
	return DOMUtils.getText(getDataContent());
    }

}

// end of DOMContentItem.java
