// DOMNewsIdentifier.java - DOM implementation of NewsIdentifier.
// Copyright (c) 2000 by Reuters PLC and Wavo Company, Inc.
// Copyright (c) 2001 by Reuters PLC.
// $Id: DOMNewsIdentifier.java,v 1.10 2001/05/23 01:56:18 david Exp $

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.newsml.toolkit.dom;

import org.w3c.dom.Node;

import org.newsml.toolkit.FormalName;
import org.newsml.toolkit.NewsIdentifier;
import org.newsml.toolkit.NewsItemId;
import org.newsml.toolkit.ProviderId;
import org.newsml.toolkit.RevisionId;


/**
 * DOM implementation of NewsIdentifier.
 *
 * @author Reuters PLC
 * @version 1.0
 */
class DOMNewsIdentifier
    extends DOMBaseNode
    implements NewsIdentifier
{

    /**
     * Constructor.
     *
     * @param element The DOM node representing the news identifier.
     */
    protected DOMNewsIdentifier (Node element, DOMNewsMLSession session)
    {
	super(element, session);
    }


    /**
     * @see NewsIdentifier#getProviderId()
     */
    public ProviderId getProviderId ()
    {
	Node e = getDOMChild("ProviderId");
	return (e == null ? null : new NewsIdentifierFormalName(e, session));
    }


    /**
     * @see NewsIdentifier#getDateId()
     */
    public String getDateId ()
    {
	return getDOMContent("DateId");
    }


    /**
     * @see NewsIdentifier#getNewsItemId()
     */
    public NewsItemId getNewsItemId ()
    {
	Node e = getDOMChild("NewsItemId");
	return (e == null ? null : new NewsIdentifierFormalName(e, session));
    }


    /**
     * @see NewsIdentifier#getRevisionId()
     */
    public RevisionId getRevisionId ()
    {
	Node e = getDOMChild("RevisionId");
	return (e == null ? null : new DOMRevisionId(e, session));
    }


    /**
     * @see NewsIdentifier#getPublicIdentifier()
     */
    public String getPublicIdentifier ()
    {
	return getDOMContent("PublicIdentifier");
    }



    ////////////////////////////////////////////////////////////////////
    // Inner class.
    ////////////////////////////////////////////////////////////////////

    /**
     * Formal name for news identifier parts.
     *
     * <p>News identifiers have vocabulary- and scheme-qualified
     * names, but with a different type of markup (the local name
     * part is represented by character data content rather than
     * a Name attribute).  This class hides the differences from
     * applications.</p>
     */
    protected class NewsIdentifierFormalName
	extends DOMFormalName
	implements NewsItemId, ProviderId
    {

	/**
	 * Constructor.
	 *
	 * @param element The DOM node containing the formal name
	 * information.
	 */
	protected NewsIdentifierFormalName (Node element, DOMNewsMLSession session)
	{
	    super(element, session);
	}


	/**
	 * @see FormalName#getName()
	 */
	public String getName ()
	{
	    return DOMUtils.getText(getDOMNode());
	}

    }

}

// end of DOMNewsIdentifier.java
