// DOMNewsItem.java - DOM implementation of NewsItem.
// Copyright (c) 2000 by Reuters PLC and Wavo Company, Inc.
// Copyright (c) 2001 by Reuters PLC.
// $Id: DOMNewsItem.java,v 1.13 2001/05/23 01:56:19 david Exp $

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.newsml.toolkit.dom;

import org.w3c.dom.Node;

import org.newsml.toolkit.FormalName;
import org.newsml.toolkit.Identification;
import org.newsml.toolkit.Label;
import org.newsml.toolkit.NewsComponent;
import org.newsml.toolkit.NewsIdentifier;
import org.newsml.toolkit.NewsItem;
import org.newsml.toolkit.NewsManagement;
import org.newsml.toolkit.PrimaryNode;
import org.newsml.toolkit.Text;
import org.newsml.toolkit.TopicSet;


/**
 * DOM implementation of NewsItem.
 *
 * @author Reuters PLC
 * @version 1.0
 */
class DOMNewsItem
    extends DOMPrimaryNode
    implements NewsItem
{

    /**
     * Constructor.
     *
     * @param element The DOM node representing the news item.
     */
    protected DOMNewsItem (Node element, DOMNewsMLSession session)
    {
	super(element, session);
    }


    /**
     * @see NewsItem#getType()
     */
    public int getType ()
    {
	return PrimaryNode.NEWS_ITEM;
    }


    /**
     * @see NewsItem#getIdentification()
     */
    public Identification getIdentification ()
    {
	Node e = getDOMChild("Identification");
	return (e == null ? null : new DOMIdentification(e, session));
    }


    /**
     * @see NewsItem#getNewsManagement()
     */
    public NewsManagement getNewsManagement ()
    {
	Node e = getDOMChild("NewsManagement");
	return (e == null ? null : new DOMNewsManagement(e, session));
    }


    /**
     * @see NewsItem#getRootNewsComponent()
     */
    public NewsComponent getRootNewsComponent ()
    {
	Node e = getDOMChild("NewsComponent");
	return (e == null ? null : new DOMNewsComponent(e, session));
    }


    /**
     * @see NewsItem#getRootTopicSet()
     */
    public TopicSet getRootTopicSet ()
    {
	Node e = getDOMChild("TopicSet");
	return (e == null ? null : new DOMTopicSet(e, session));
    }


    /**
     * Inner class implementing Identification.
     */
    class DOMIdentification
	extends DOMBaseNode
	implements Identification
    {

	/**
	 * Constructor.
	 */
	public DOMIdentification (Node e, DOMNewsMLSession session)
	{
	    super(e, session);
	}


	/**
	 * @see Identification.getNewsIdentifier()
	 */
	public NewsIdentifier getNewsIdentifier ()
	{
	    Node e = getDOMChild("NewsIdentifier");
	    return (e == null ? null : new DOMNewsIdentifier(e, session));
	}


	/**
	 * @see Identification.getNameLabel()
	 */
	public Text getNameLabel ()
	{
	    return getDOMText("NameLabel");
	}


	/**
	 * @see Identification.getDateLabel()
	 */
	public Text getDateLabel ()
	{
	    return getDOMText("DateLabel");
	}


	/**
	 * @see Identification.getLabelCount()
	 */
	public int getLabelCount ()
	{
	    return getDOMChildCount("Label");
	}


	/**
	 * @see Identification.getLabel(int)
	 */
	public Label getLabel (int index)
	{
	    Node e = getDOMChild("Label", index);
	    return (e == null ? null : new DOMLabel(e, session));
	}


	/**
	 * @see Identification.getLabel()
	 */
	public Label [] getLabel ()
	{
	    int len = getLabelCount();
	    Label ret[] = new Label[len];
	    for (int i = 0; i < len; i++)
		ret[i] = getLabel(i);
	    return ret;
	}

    }


    /**
     * Inner class implementing Label.
     */
    class DOMLabel
	extends DOMBaseNode
	implements Label
    {


	/**
	 * Constructor.
	 */
	public DOMLabel (Node e, DOMNewsMLSession session)
	{
	    super(e, session);
	}


	/**
	 * @see Label#getLabelType()
	 */
	public FormalName getLabelType ()
	{
	    return getDOMFormalName("LabelType", 0);
	}


	/**
	 * @see Label#getLabelText()
	 */
	public Text getLabelText ()
	{
	    return getDOMText("LabelText");
	}

    }

}

// end of DOMNewsItem.java
