// DOMNewsManagement.java - DOM implementation of NewsManagement.
// Copyright (c) 2000 by Reuters PLC and Wavo Company, Inc.
// Copyright (c) 2001 by Reuters PLC.
// $Id: DOMNewsManagement.java,v 1.12 2001/05/23 01:56:19 david Exp $

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.newsml.toolkit.dom;

import org.w3c.dom.Node;

import org.newsml.toolkit.FormalName;
import org.newsml.toolkit.Instruction;
import org.newsml.toolkit.NewsItemRef;
import org.newsml.toolkit.NewsManagement;
import org.newsml.toolkit.RevisionHistory;
import org.newsml.toolkit.StatusWillChange;
import org.newsml.toolkit.Text;


/**
 * DOM implementation of NewsManagement.
 *
 * @author Reuters PLC
 * @version 1.0
 */
class DOMNewsManagement
    extends DOMBaseNode
    implements NewsManagement
{


    /**
     * Constructor.
     *
     * @param element The DOM node representing the NewsManagement object.
     */
    protected DOMNewsManagement (Node element, DOMNewsMLSession session)
    {
	super(element, session);
    }


    /**
     * @see NewsManagement#getNewsItemType()
     */
    public FormalName getNewsItemType ()
    {
	return getDOMFormalName("NewsItemType", 0);
    }


    /**
     * @see NewsManagement#getFirstCreated()
     */
    public Text getFirstCreated ()
    {
	return getDOMText("FirstCreated");
    }


    /**
     * @see NewsManagement#getThisRevisionCreated()
     */
    public Text getThisRevisionCreated ()
    {
	return getDOMText("ThisRevisionCreated");
    }


    /**
     * @see NewsManagement#getStatus()
     */
    public FormalName getStatus ()
    {
	return getDOMFormalName("Status", 0);
    }


    /**
     * @see NewsManagement#getStatusWillChange()
     */
    public StatusWillChange getStatusWillChange ()
    {
	Node e = getDOMChild("StatusWillChange");
	return (e == null ? null : new DOMStatusWillChange(e, session));
    }


    /**
     * @see NewsManagement#getUrgency()
     */
    public FormalName getUrgency ()
    {
	return getDOMFormalName("Urgency", 0);
    }


    /**
     * @see NewsManagement#getRevisionHistory()
     */
    public RevisionHistory getRevisionHistory ()
    {
	Node e = getDOMChild("RevisionHistory");
	return (e == null ? null : new DOMBaseNode(e, session));
    }


    /**
     * @see NewsManagement#getDerivedFromCount()
     */
    public int getDerivedFromCount ()
    {
	return getDOMChildCount("DerivedFrom");
    }


    /**
     * @see NewsManagement#getDerivedFrom(int)
     */
    public NewsItemRef getDerivedFrom (int index)
    {
	Node e = getDOMChild("DerivedFrom", index);
	return (e == null ? null : new DOMNewsItemRef(e, session));
    }


    /**
     * @see NewsManagement#getDerivedFrom()
     */
    public NewsItemRef [] getDerivedFrom ()
    {
	int len = getDerivedFromCount();
	NewsItemRef ret[] = new NewsItemRef[len];
	for (int i = 0; i < len; i++)
	    ret[i] = getDerivedFrom(i);
	return ret;
    }


    /**
     * @see NewsManagement#getAssociatedWithCount()
     */
    public int getAssociatedWithCount ()
    {
	return getDOMChildCount("AssociatedWith");
    }


    /**
     * @see NewsManagement#getAssociatedWith(int)
     */
    public NewsItemRef getAssociatedWith (int index)
    {
	Node e = getDOMChild("AssociatedWith", index);
	return (e == null ? null : new DOMNewsItemRef(e, session));
    }


    /**
     * @see NewsManagement#getAssociatedWith()
     */
    public NewsItemRef [] getAssociatedWith ()
    {
	int len = getAssociatedWithCount();
	NewsItemRef ret[] = new NewsItemRef[len];
	for (int i = 0; i < len; i++)
	    ret[i] = getAssociatedWith(i);
	return ret;
    }


    /**
     * @see NewsManagement#getInstructionCount()
     */
    public int getInstructionCount ()
    {
	return getDOMChildCount("Instruction");
    }


    /**
     * @see NewsManagement#getInstruction(int)
     */
    public Instruction getInstruction (int index)
    {
	Node e = getDOMChild("Instruction", index);
	return (e == null ? null : new DOMInstruction(e, session));
    }



    /**
     * @see NewsManagement#getInstruction()
     */
    public Instruction [] getInstruction ()
    {
	int len = getInstructionCount();
	Instruction ret[] = new Instruction[len];
	for (int i = 0; i < len; i++)
	    ret[i] = getInstruction(i);
	return ret;
    }

}

// end of DOMNewsManagement.java
