// DOMPartyList.java - DOM implementation of PartyList.
// Copyright (c) 2001 by Reuters PLC.
// $Id: DOMPartyList.java,v 1.8 2001/05/23 01:56:19 david Exp $

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.newsml.toolkit.dom;

import org.w3c.dom.Node;

import org.newsml.toolkit.PartyList;
import org.newsml.toolkit.Party;
import org.newsml.toolkit.SourceList;


/**
 * DOM implementation of PartyList.
 *
 * @author Reuters PLC
 * @version 1.0
 */
class DOMPartyList
    extends DOMBaseNode
    implements PartyList, SourceList
{

    /**
     * Constructor.
     *
     * @param element The DOM node representing list of formal names.
     */
    protected DOMPartyList (Node element, DOMNewsMLSession session)
    {
	super(element, session);
    }


    /**
     * @see PartyList#getPartyCount()
     */
    public int getPartyCount ()
    {
	return getDOMChildCount("Party");
    }


    /**
     * @see PartyList#getParty(int)
     */
    public Party getParty (int index)
    {
	Node e = getDOMChild("Party", index);
	return (e == null ? null : new DOMParty(e, session));
    }


    /**
     * @see PartyList#getParty()
     */
    public Party [] getParty ()
    {
	int len = getPartyCount();
	Party ret[] = new Party[len];
	for (int i = 0; i < len; i++)
	    ret[i] = getParty(i);
	return ret;
    }


    /**
     * @see PartyList#getNewsItemURN
     */
    public String getNewsItemURN ()
    {
	return getDOMAttribute("NewsItem");
    }

}

// end of DOMPartyList.java
