// DOMPrimaryNode.java - DOM implementation of PrimaryNode.
// Copyright (c) 2000 by Reuters PLC and Wavo Company, Inc.
// Copyright (c) 2001 by Reuters PLC.
// $Id: DOMPrimaryNode.java,v 1.12 2001/05/23 01:56:19 david Exp $

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.newsml.toolkit.dom;

import java.util.ArrayList;

import org.w3c.dom.Node;

import org.newsml.toolkit.BaseNode;
import org.newsml.toolkit.ContentItem;
import org.newsml.toolkit.NewsComponent;
import org.newsml.toolkit.NewsItem;
import org.newsml.toolkit.NewsItemRef;
import org.newsml.toolkit.NewsML;
import org.newsml.toolkit.PrimaryNode;


/**
 * DOM implementation of PrimaryNode.
 *
 * @author Reuters PLC
 * @version 1.0
 */
abstract class DOMPrimaryNode
    extends DOMBaseNode
    implements PrimaryNode
{


    /**
     * Constructor.
     */
    protected DOMPrimaryNode (Node element, DOMNewsMLSession session)
    {
	super(element, session);
    }


    /**
     * @see PrimaryNode#getType()
     */
    public abstract int getType ();


    /**
     * @see PrimaryNode#getParent()
     */ 
    public PrimaryNode getParent ()
    {
	Node element = getDOMNode().getParentNode();
	if (element == null)
	    return null;
	String name = element.getNodeName();
	if ("NewsML".equals(name))
	    return new DOMNewsML(element, session);
	else if ("NewsItem".equals(name))
	    return new DOMNewsItem(element, session);
	else if ("NewsItemRef".equals(name))
	    return new DOMNewsItemRef(element, session);
	else if ("NewsComponent".equals(name))
	    return new DOMNewsComponent(element, session);
	else if ("ContentItem".equals(name))
	    return new DOMContentItem(element, session);
	else
	    return null;
    }


    /**
     * @see PrimaryNode#getChildCount()
     */
    public int getChildCount ()
    {
	switch (getType()) {
	case NEWSML:
	    return asNewsML().getNewsItemCount();
	case NEWS_ITEM:
	    return (asNewsItem().getRootNewsComponent() == null ? 0 : 1);
	case NEWS_COMPONENT:
	    return asNewsComponent().getMemberCount();
	case NEWS_ITEM_REF:
	case CONTENT_ITEM:
	    return 0;
	}

	return 0;
    }


    /**
     * @see PrimaryNode#getChild(int)
     */
    public PrimaryNode getChild (int index)
    {
	switch (getType()) {
	case NEWSML:
	    return asNewsML().getNewsItem(index);
	case NEWS_ITEM:
	    return (index == 0 ? asNewsItem().getRootNewsComponent() : null);
	case NEWS_COMPONENT:
	    return asNewsComponent().getMember(index);
	case NEWS_ITEM_REF:
	case CONTENT_ITEM:
	    return null;
	}

	return null;
    }


    /**
     * @see PrimaryNode#getChild()
     */
    public PrimaryNode [] getChild ()
    {
	int len = getChildCount();
	PrimaryNode ret[] = new PrimaryNode[len];
	for (int i = 0; i < len; i++)
	    ret[i] = getChild(i);
	return ret;
    }


    /**
     * @see PrimaryNode#asNewsML()
     */
    public NewsML asNewsML ()
    {
	return (getType() == NEWSML ? (NewsML)this : null);
    }


    /**
     * @see PrimaryNode#asNewsItem()
     */
    public NewsItem asNewsItem ()
    {
	return (getType() == NEWS_ITEM ? (NewsItem)this : null);
    }


    /**
     * @see PrimaryNode#asNewsComponent()
     */
    public NewsComponent asNewsComponent ()
    {
	return (getType() == NEWS_COMPONENT ? (NewsComponent)this : null);
    }


    /**
     * @see PrimaryNode#asNewsItemRef()
     */
    public NewsItemRef asNewsItemRef ()
    {
	return (getType() == NEWS_ITEM_REF ? (NewsItemRef)this : null);
    }


    /**
     * @see PrimaryNode#asContentItem()
     */
    public ContentItem asContentItem ()
    {
	return (getType() == CONTENT_ITEM ? (ContentItem)this : null);
    }


    /**
     * @see PrimaryNode#getNodePath()
     */
    public PrimaryNode [] getNodePath ()
    {
	ArrayList path = new ArrayList();
	PrimaryNode node = this;
	while (node != null) {
	    path.add(0, node);
	    node = node.getParent();
	}
	Object objectPath[] = path.toArray();
	PrimaryNode nodePath[] = new PrimaryNode[objectPath.length];
	java.lang.System.arraycopy(objectPath, 0,
				   nodePath, 0,
				   objectPath.length);
	return nodePath;
    }

}

// end of DOMPrimaryNode.java
