// DOMResource.java - DOM implementation of Resource.
// Copyright (c) 2001 by Reuters PLC.
// $Id: DOMResource.java,v 1.11 2001/05/23 01:56:19 david Exp $

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.newsml.toolkit.dom;

import org.w3c.dom.Node;

import org.newsml.toolkit.DefaultVocabularyFor;
import org.newsml.toolkit.Resource;
import org.newsml.toolkit.Text;


/**
 * DOM implementation of Resource.
 *
 * @author Reuters PLC
 * @version 1.0
 */
class DOMResource
    extends DOMBaseNode
    implements Resource
{

    /**
     * Constructor.
     *
     * @param element The DOM node representing the basis for choice.
     */
    protected DOMResource (Node element, DOMNewsMLSession session)
    {
	super(element, session);
    }


    /**
     * @see Property#getUrn()
     */
    public Text getUrn ()
    {
	return getDOMText("Urn");
    }


    /**
     * @see Property#getUrlCount()
     */
    public int getUrlCount ()
    {
	return getDOMChildCount("Url");
    }


    /**
     * @see Property#getUrl(int)
     */
    public Text getUrl (int index)
    {
	return getDOMText("Url", index);
    }


    /**
     * @see Resource#getUrl()
     */
    public Text [] getUrl ()
    {
	int len = getUrlCount();
	Text ret[] = new Text[len];
	for (int i = 0; i < len; i++)
	    ret[i] = getUrl(i);
	return ret;
    }


    /**
     * @see Property#getDefaultVocabularyForCount()
     */
    public int getDefaultVocabularyForCount ()
    {
	return getDOMChildCount("DefaultVocabularyFor");
    }


    /**
     * @see Property#getDefaultVocabularyFor(int)
     */
    public DefaultVocabularyFor getDefaultVocabularyFor (int index)
    {
	Node e = getDOMChild("DefaultVocabularyFor", index);
	return (e == null ? null : new DOMDefaultVocabularyFor(e, session));
    }

    
    /**
     * @see Resource#getDefaultVocabularyFor()
     */
    public DefaultVocabularyFor [] getDefaultVocabularyFor ()
    {
	int len = getDefaultVocabularyForCount();
	DefaultVocabularyFor ret[] = new DefaultVocabularyFor[len];
	for (int i = 0; i < len; i++)
	    ret[i] = getDefaultVocabularyFor(i);
	return ret;
    }


    /**
     * Inner class implementing DefaultVocabularyFor
     */
    protected class DOMDefaultVocabularyFor
	extends DOMBaseNode
	implements DefaultVocabularyFor
    {
	protected DOMDefaultVocabularyFor(Node e, DOMNewsMLSession session)
	{
	    super(e, session);
	}


	/**
	 * @see DefaultVocabularyFor#getContext()
	 */
	public String getContext ()
	{
	    return getDOMAttribute("Context");
	}


	/**
	 * @see DefaultVocabularyFor#getScheme()
	 */
	public String getScheme ()
	{
	    return getDOMAttribute("Scheme");
	}

    }

}

// end of DOMResource.java
