// DOMRevisionId.java - DOM implementation of RevisionId.
// Copyright (c) 2000 by Reuters PLC and Wavo Company, Inc.
// Copyright (c) 2001 by Reuters PLC.
// $Id: DOMRevisionId.java,v 1.10 2001/05/23 01:56:19 david Exp $

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.newsml.toolkit.dom;

import org.w3c.dom.Node;

import org.newsml.toolkit.RevisionId;


/**
 * DOM implementation of RevisionId.
 *
 * @author Reuters PLC
 * @version 1.0
 */
class DOMRevisionId
    extends DOMBaseNode
    implements RevisionId
{

    /**
     * Constructor.
     *
     * @param element The DOM node representing the revision ID.
     */
    protected DOMRevisionId (Node element, DOMNewsMLSession session)
    {
	super(element, session);
    }


    /**
     * @see RevisionId#getValue()
     */
    public int getValue ()
    {
	String value = DOMUtils.getText(getDOMNode());
	return (value == null ? -1 : Integer.parseInt(value));
    }


    /**
     * @see RevisionId#getPreviousRevision()
     */
    public int getPreviousRevision ()
    {
	String value = getDOMAttribute("PreviousRevision");
	return (value == null ? -1 : Integer.parseInt(value));
    }


    /**
     * @see RevisionId#getUpdate()
     */
    public String getUpdate ()
    {
	return getDOMAttribute("Update");
    }

}

// end of DOMRevisionId.java
