// DOMRightsMetadata.java - DOM implementation of RightsMetadata.
// Copyright (c) 2000 by Reuters PLC and Wavo Company, Inc.
// Copyright (c) 2001 by Reuters PLC.
// $Id: DOMRightsMetadata.java,v 1.11 2001/05/23 01:56:19 david Exp $

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.newsml.toolkit.dom;

import org.w3c.dom.Node;

import org.newsml.toolkit.Copyright;
import org.newsml.toolkit.UsageRights;
import org.newsml.toolkit.RightsMetadata;


/**
 * DOM implementation of RightsMetadata.
 *
 * @author Reuters PLC
 * @version 1.0
 */
class DOMRightsMetadata
    extends DOMBaseNode
    implements RightsMetadata
{

    /**
     * Constructor.
     *
     * @param element The DOM node representing the usage rights.
     */
    protected DOMRightsMetadata (Node element, DOMNewsMLSession session)
    {
	super(element, session);
    }


    /**
     * @see RightsMetadata#getCopyrightCount()
     */
    public int getCopyrightCount ()
    {
	return getDOMChildCount("Copyright");
    }


    /**
     * @see RightsMetadata#getCopyright(int)
     */
    public Copyright getCopyright (int index)
    {
	Node e = getDOMChild("Copyright", index);
	return (e == null ? null : new DOMCopyright(e, session));
    }


    /**
     * @see RightsMetadata#getCopyright()
     */
    public Copyright [] getCopyright ()
    {
	int len = getCopyrightCount();
	Copyright ret[] = new Copyright[len];
	for (int i = 0; i < len; i++)
	    ret[i] = getCopyright(i);
	return ret;
    }


    /**
     * @see RightsMetadata#getUsageRightsCount()
     */
    public int getUsageRightsCount ()
    {
	return getDOMChildCount("UsageRights");
    }


    /**
     * @see RightsMetadata#getUsageRights(int)
     */
    public UsageRights getUsageRights (int index)
    {
	Node e = getDOMChild("UsageRights", index);
	return (e == null ? null : new DOMUsageRights(e, session));
    }


    /**
     * @see RightsMetadata#getUsageRights()
     */
    public UsageRights [] getUsageRights ()
    {
	int len = getUsageRightsCount();
	UsageRights ret[] = new UsageRights[len];
	for (int i = 0; i < len; i++)
	    ret[i] = getUsageRights(i);
	return ret;
    }


}

// end of DOMRightsMetadata.java
