// DOMTopicSet.java - DOM implementation of TopicSet.
// Copyright (c) 2001 by Reuters PLC.
// $Id: DOMTopicSet.java,v 1.13 2001/05/23 01:56:19 david Exp $

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.newsml.toolkit.dom;

import org.w3c.dom.Node;

import org.newsml.toolkit.FormalName;
import org.newsml.toolkit.Topic;
import org.newsml.toolkit.TopicSet;
import org.newsml.toolkit.TopicSetRef;


/**
 * DOM implementation of TopicSet.
 *
 * @author Reuters PLC
 * @version 1.0
 */
class DOMTopicSet
    extends DOMFormalName
    implements TopicSet
{

    /**
     * Constructor.
     */
    protected DOMTopicSet (Node element, DOMNewsMLSession session)
    {
	super(element, session);
    }


    /**
     * @see TopicSet#getTopicSetRefCount()
     */
    public int getTopicSetRefCount ()
    {
	return getDOMChildCount("TopicSetRef");
    }


    /**
     * @see TopicSet#getTopicSetRef(int)
     */
    public TopicSetRef getTopicSetRef (int index)
    {
	Node e = getDOMChild("TopicSetRef", index);
	return (e == null ? null : new DOMTopicSetRef(e, session));
    }


    /**
     * @see TopicSet#getTopicSetRef()
     */
    public TopicSetRef [] getTopicSetRef ()
    {
	int len = getTopicSetRefCount();
	TopicSetRef ret[] = new TopicSetRef[len];
	for (int i = 0; i < len; i++)
	    ret[i] = getTopicSetRef(i);
	return ret;
    }


    /**
     * @see TopicSet#getTopicCount()
     */
    public int getTopicCount ()
    {
	return getDOMChildCount("Topic");
    }


    /**
     * @see TopicSet#getTopic(int)
     */
    public Topic getTopic (int index)
    {
	Node e = getDOMChild("Topic", index);
	return (e == null ? null : new DOMTopic(e, session));
    }


    /**
     * @see TopicSet#getTopic()
     */
    public Topic [] getTopic ()
    {
	int len = getTopicCount();
	Topic ret[] = new Topic[len];
	for (int i = 0; i < len; i++)
	    ret[i] = getTopic(i);
	return ret;
    }


    /**
     * Inner class implementing TopicSetRef.
     */
    class DOMTopicSetRef
	extends DOMBaseNode
	implements TopicSetRef
    {


	/**
	 * Constructor.
	 */
	DOMTopicSetRef (Node e, DOMNewsMLSession session)
	{
	    super(e, session);
	}


	/**
	 * @see TopicSetRef#getRef()
	 */
	public String getRef ()
	{
	    return getDOMAttribute("TopicSet");
	}

    }

}

// end of DOMTopicSet.java
