// ContentItemTest.java - unit tests for org.newsml.toolkit.dom.ContentItem

package org.newsml.toolkit.dom.unittests;

import java.io.IOException;

import org.xml.sax.SAXException;

import org.newsml.toolkit.ContentItem;
import org.newsml.toolkit.PrimaryNode;


public class ContentItemTest extends PrimaryNodeTestBase
{

    public ContentItemTest (String name)
    {
	super(name);
    }

    protected void setUp ()
	throws Exception
    {
	super.setUp();
	sample =
	    SampleFactory.createNewsML().getNewsItem(0)
	    .getRootNewsComponent().getMember(1).asNewsComponent()
	    .getMember(0).asContentItem();
	sample2 =
	    sample.getParent().asNewsComponent().getMember(1)
	    .asContentItem();
    }

    public void testType ()
    {
	assertEquals(sample.getType(), PrimaryNode.CONTENT_ITEM);
    }

    public void testBase ()
    {
	assertEquals(sample.getXMLName(), "ContentItem");
	assertNotNull(sample.getSession());
    }

    public void testIdentifiers ()
    {
	assertEquals(sample.getDuid(), "con01");
	assertEquals(sample.getEuid(), "id1");
    }

    public void testHref ()
    {
	assertEquals(sample.getHref(),
		     "http://www.acmenews.com/story1.xml");
    }

    public void testComment ()
    {
	assertEquals(sample.getCommentCount(), 2);
        assertEquals(sample.getComment().length, 2);
	assertNotNull(sample.getComment(0));
	assertNotNull(sample.getComment(1));
	assertNull(sample.getComment(2));
    }

    public void testCatalog ()
    {
	assertNotNull(sample.getCatalog());
    }

    public void testMediaType ()
    {
	assertEquals(sample.getMediaType().getName(), "text");
    }

    public void testFormat ()
    {
	assertEquals(sample.getFormat().getName(), "nitf");
    }

    public void testMimeType ()
    {
	assertEquals(sample.getMimeType().getName(), "text/x-nitf");
    }

    public void testNotation ()
    {
	assertEquals(sample.getNotation().getName(), "nitf-xml");
    }

    public void testCharacteristics ()
    {
	assertNotNull(sample.getCharacteristics());
    }

    public void testEncoding ()
    {
	assertEquals(sample2.getEncodingCount(), 2);
	assertEquals(sample2.getEncoding(0), "zip");
	assertEquals(sample2.getEncoding(1), "base64");
	assertNull(sample2.getEncoding(2));
    }

    public void testDataContent ()
    {
				// TODO: test actual content
	assertNotNull(sample2.getDataContent());
    }

    public void testDataText ()
    {
	assertEquals(sample2.getDataText(), "This is a test.");
    }

    public void testParent ()
    {
	assertNotNull(sample.getParent());
	assertEquals(sample.getParent().getType(),
		     PrimaryNode.NEWS_COMPONENT);
    }

    public void testChildren ()
    {
	assertEquals(sample.getChildCount(), 0);
	assertNull(sample.getChild(0));
    }

    public void testContentItemCast ()
    {
	assertNotNull(sample.asContentItem());
    }

    protected PrimaryNode getPrimaryNode ()
    {
	return sample;
    }

    private ContentItem sample;
    private ContentItem sample2;

}

// end of ContentItemTest.java
