// FormalNameTest.java - unit tests for FormalName

package org.newsml.toolkit.dom.unittests;

import java.io.IOException;

import junit.framework.TestCase;

import org.newsml.toolkit.FormalName;

public class FormalNameTest extends TestCase
{

    public FormalNameTest (String name)
    {
	super(name);
    }

    protected void setUp ()
	throws Exception
    {
	super.setUp();
	sample = SampleFactory.createNewsML().getNewsItem(0)
	    .getNewsManagement().getNewsItemType();
	sample2 = SampleFactory.createNewsML().getTopicSet(1).getTopic(0)
	    .getTopicType(0);
    }

    public void testBase ()
    {
	assertEquals(sample.getXMLName(), "NewsItemType");
	assertNotNull(sample.getSession());
    }

    public void testIdentifiers ()
    {
	assertEquals(sample.getDuid(), "newsitemtype01");
	assertEquals(sample.getEuid(), "id1");
	assertEquals(sample2.getDuid(), "topictype-x");
    }

    public void testName ()
    {
	assertEquals(sample.getName(), "item.type");
    }

    public void testVocabulary ()
    {
	assertEquals(sample.getVocabulary(), "#vocab.a");
	assertNull(sample2.getVocabulary());
    }

    public void testInternalDefaultVocabulary ()
	throws IOException
    {
	assertEquals(sample.getDefaultVocabulary(false), "#vocab.a");
	assertEquals(sample2.getDefaultVocabulary(false), "#vocab.b");
    }

    public void testExternalDefaultVocabulary ()
	throws IOException
    {
	assertEquals(sample.getDefaultVocabulary(true), "#vocab.a");
	assertEquals(sample2.getDefaultVocabulary(true),
		     "http://www.foo.com/topicset.xml");
    }

    public void testScheme ()
    {
	assertEquals(sample.getScheme(), "scheme.a");
    }

    public void testInternalDefaultScheme ()
	throws IOException
    {
	assertEquals(sample2.getDefaultScheme(false), "Scheme");
    }

    public void testTopicSet ()
	throws IOException
    {
	assertNotNull(sample.getTopicSet(false));
	assertEquals(sample.getTopicSet(false).getName(), "topicset.e");
    }

    public void testDefaultTopicSet ()
	throws IOException
    {
	assertNotNull(sample2.getTopicSet(false));
	assertEquals(sample2.getTopicSet(false).getName(), "topicset.d");
    }

    public void testToString ()
	throws IOException
    {
	assertEquals(sample.toString(), "{#vocab.a}{scheme.a}item.type");
	assertEquals(sample2.toString(), "{}{}topic.a");
	assertEquals(sample2.toString(false), "{#vocab.b}{Scheme}topic.a");
	assertEquals(sample2.toString(true),
		     "{http://www.foo.com/topicset.xml}{}topic.a");
    }

    protected FormalName sample;
    protected FormalName sample2;

}

// end of FormalNameTest.java
