// NewsComponentTest.java - unit tests for org.newsml.toolkit.dom.NewsComponent

package org.newsml.toolkit.dom.unittests;

import java.io.IOException;

import org.xml.sax.SAXException;

import org.newsml.toolkit.NewsComponent;
import org.newsml.toolkit.PrimaryNode;


public class NewsComponentTest extends PrimaryNodeTestBase
{

    public NewsComponentTest (String name)
    {
	super(name);
    }

    protected void setUp ()
	throws Exception
    {
	super.setUp();
	sample =
	    SampleFactory.createNewsML().getNewsItem(0).getRootNewsComponent();
    }

    public void testType ()
    {
	assertEquals(sample.getType(), PrimaryNode.NEWS_COMPONENT);
    }

    public void testBase ()
    {
	assertEquals(sample.getXMLName(), "NewsComponent");
	assertNotNull(sample.getSession());
    }

    public void testIdentifiers ()
    {
	assertEquals(sample.getDuid(), "newscomponent01");
	assertEquals(sample.getEuid(), "id1");
    }

    public void testEssential ()
    {
	assert(!sample.isEssential());
    }

    public void testEquivalents ()
    {
	assert(sample.isEquivalentsList());
    }

    public void testLanguage ()
    {
	assertEquals(sample.getLang(), "en");
    }

    public void testComment ()
    {
	assertEquals(sample.getCommentCount(), 2);
        assertEquals(sample.getComment().length, 2);
	assertNotNull(sample.getComment(0));
	assertNotNull(sample.getComment(1));
	assertNull(sample.getComment(2));
    }

    public void testCatalog ()
    {
	assertNotNull(sample.getCatalog());
    }

    public void testTopicSet ()
    {
	assertEquals(sample.getTopicSetCount(), 2);
        assertEquals(sample.getTopicSet().length, 2);
	assertNotNull(sample.getTopicSet(0));
	assertNotNull(sample.getTopicSet(1));
	assertNull(sample.getTopicSet(2));
    }

    public void testRole ()
    {
	assertNotNull(sample.getRole());
	assertEquals(sample.getRole().getName(), "story");
    }

    public void testBasisForChoice ()
    {
	assertEquals(sample.getBasisForChoiceCount(), 1);
	assertEquals(sample.getBasisForChoice().length, 1);
	assertNotNull(sample.getBasisForChoice(0));
	assertNull(sample.getBasisForChoice(1));
    }

    public void testNewsLines ()
    {
	assertNotNull(sample.getNewsLines());
    }

    public void testAdministrativeMetadata ()
    {
	assertNotNull(sample.getAdministrativeMetadata());
    }

    public void testRightsMetadata ()
    {
	assertNotNull(sample.getRightsMetadata());
    }

    public void testDescriptiveMetadata ()
    {
	assertNotNull(sample.getDescriptiveMetadata());
    }

    public void testMetadata ()
    {
	assertEquals(sample.getMetadataCount(), 1);
	assertEquals(sample.getMetadata().length, 1);
	assertNotNull(sample.getMetadata(0));
	assertNull(sample.getMetadata(1));
    }

    public void testMember ()
    {
	assertEquals(sample.getMemberCount(), 2);
        assertEquals(sample.getMember().length, 2);
	assertNotNull(sample.getMember(0));
	assertNotNull(sample.getMember(1));
	assertNull(sample.getMember(2));
    }

    public void testParent ()
    {
	assertNotNull(sample.getParent());
	assertEquals(sample.getParent().getType(),
		     PrimaryNode.NEWS_ITEM);
    }

    public void testChildren ()
    {
	assertEquals(sample.getChildCount(), 2);
        assertEquals(sample.getChild().length, 2);
	assertNotNull(sample.getChild(0));
	assertNotNull(sample.getChild(1));
	assertNull(sample.getChild(2));
	assertEquals(sample.getChild(0).getType(),
		     PrimaryNode.NEWS_COMPONENT);
	assertEquals(sample.getChild(1).getType(),
		     PrimaryNode.NEWS_COMPONENT);
    }

    public void testNewsComponentCast ()
    {
	assertNotNull(sample.asNewsComponent());
    }

    protected PrimaryNode getPrimaryNode ()
    {
	return sample;
    }

    private NewsComponent sample;

}

// end of NewsComponentTest.java
