// NewsItemRefTest.java - unit tests for org.newsml.toolkit.dom.NewsItemRef

package org.newsml.toolkit.dom.unittests;

import java.io.IOException;

import org.xml.sax.SAXException;

import org.newsml.toolkit.NewsItemRef;
import org.newsml.toolkit.PrimaryNode;


public class NewsItemRefTest extends PrimaryNodeTestBase
{

    public NewsItemRefTest (String name)
    {
	super(name);
    }

    protected void setUp ()
	throws Exception
    {
	super.setUp();
	sample =
	    SampleFactory.createNewsML().getNewsItem(0)
	    .getRootNewsComponent().getMember(0)
	    .asNewsComponent().getMember(0).asNewsItemRef();
	sample2 =
	    SampleFactory.createNewsML().getNewsItem(0)
	    .getRootNewsComponent().getMember(0)
	    .asNewsComponent().getMember(1).asNewsItemRef();
    }

    public void testBase ()
    {
	assertEquals(sample.getXMLName(), "NewsItemRef");
	assertNotNull(sample.getSession());
    }

    public void testType ()
    {
	assertEquals(sample.getType(), PrimaryNode.NEWS_ITEM_REF);
    }

    public void testIdentifiers ()
    {
	assertEquals(sample.getDuid(), "newsitemref01");
	assertEquals(sample.getEuid(), "id1");
    }

    public void testRef ()
    {
	assertEquals(sample.getRef(), "#newsitem-x");
    }

    public void testInternalReference ()
	throws IOException
    {
	assertNotNull(sample.getReferencedNewsItem(false));
    }

    public void testExternalReference ()
	throws IOException
    {
	assertNull(sample2.getReferencedNewsItem(false));
	assertNotNull(sample2.getReferencedNewsItem(true));
    }

    public void testComment ()
    {
	assertEquals(sample.getCommentCount(), 2);
        assertEquals(sample.getComment().length, 2);
	assertNotNull(sample.getComment(0));
	assertNotNull(sample.getComment(1));
	assertNull(sample.getComment(2));
    }

    public void testParent ()
    {
	assertNotNull(sample.getParent());
	assertEquals(sample.getParent().getType(),
		     PrimaryNode.NEWS_COMPONENT);
    }

    public void testChildren ()
    {
	assertEquals(sample.getChildCount(), 0);
	assertNull(sample.getChild(0));
    }

    public void testNewsItemRefCast ()
    {
	assertNotNull(sample.asNewsItemRef());
    }

    protected PrimaryNode getPrimaryNode ()
    {
	return sample;
    }

    private NewsItemRef sample;
    private NewsItemRef sample2;

}

// end of NewsItemRefTest.java
