// NewsItemTest.java - unit tests for org.newsml.toolkit.dom.NewsItem

package org.newsml.toolkit.dom.unittests;

import java.io.IOException;

import org.xml.sax.SAXException;

import org.newsml.toolkit.NewsItem;
import org.newsml.toolkit.PrimaryNode;


public class NewsItemTest extends PrimaryNodeTestBase
{

    public NewsItemTest (String name)
    {
	super(name);
    }

    protected void setUp ()
	throws Exception
    {
	super.setUp();
	sample = SampleFactory.createNewsML().getNewsItem(0);
	sample2 = SampleFactory.createNewsML().getNewsItem(1);
    }

    public void testType ()
    {
	assertEquals(sample.getType(), PrimaryNode.NEWS_ITEM);
    }

    public void testBase ()
    {
	assertEquals(sample.getXMLName(), "NewsItem");
	assertNotNull(sample.getSession());
    }

    public void testIdentifiers ()
    {
	assertEquals(sample.getDuid(), "newsitem01");
	assertEquals(sample.getEuid(), "id1");
    }

    public void testLanguage ()
    {
	assertEquals(sample.getLang(), "en-UK");
    }

    public void testComment ()
    {
	assertEquals(sample.getCommentCount(), 2);
        assertEquals(sample.getComment().length, 2);
	assertNotNull(sample.getComment(0));
	assertNotNull(sample.getComment(1));
	assertNull(sample.getComment(2));
    }

    public void testCatalog ()
    {
	assertNotNull(sample.getCatalog());
    }

    public void testIdentification ()
    {
	assertNotNull(sample.getIdentification());
    }

    public void testNewsManagement ()
    {
	assertNotNull(sample.getNewsManagement());
    }

    public void testRootNewsComponent ()
    {
	assertNotNull(sample.getRootNewsComponent());
	assertNull(sample.getRootTopicSet());
    }

    public void testRootTopicSet ()
    {
	assertNotNull(sample2.getRootTopicSet());
	assertNull(sample2.getRootNewsComponent());
    }

    public void testParent ()
    {
	assertNotNull(sample.getParent());
	assertEquals(sample.getParent().getType(), PrimaryNode.NEWSML);
    }

    public void testChildren ()
    {
	assertEquals(sample.getChildCount(), 1);
	assertEquals(sample.getChild().length, 1);
	assertNotNull(sample.getChild()[0]);
	assertNotNull(sample.getChild(0));
	assertNull(sample.getChild(1));
	assertEquals(sample.getChild(0).getType(),
		     PrimaryNode.NEWS_COMPONENT);
    }

    public void testNewsItemCast ()
    {
	assertNotNull(sample.asNewsItem());
    }

    protected PrimaryNode getPrimaryNode ()
    {
	return sample;
    }

    private NewsItem sample;
    private NewsItem sample2;

}

// end of NewsItemTest.java
