// NewsMLTest.java - unit tests for org.newsml.toolkit.dom.NewsML

package org.newsml.toolkit.dom.unittests;

import java.io.IOException;

import org.xml.sax.SAXException;

import org.newsml.toolkit.NewsML;
import org.newsml.toolkit.PrimaryNode;


public class NewsMLTest extends PrimaryNodeTestBase
{

    /**
     * Construct a NewsML Test with the specified name.
     *
     * @param name Test case name.
     */
    public NewsMLTest (String name)
    {
	super(name);
    }

    protected void setUp ()
	throws Exception
    {
	super.setUp();
	sample = SampleFactory.createNewsML();
    }

    public void testBase ()
    {
	assertEquals(sample.getXMLName(), "NewsML");
	assertNotNull(sample.getSession());
	assertEquals(sample.getSession().getRootNode(), sample);
    }

    public void testType ()
    {
	assertEquals(sample.getType(), PrimaryNode.NEWSML);
    }

    public void testIdentifiers ()
    {
	assertEquals(sample.getDuid(), "newsml01");
	assertEquals(sample.getEuid(), "id1");
    }

    public void testCatalog ()
    {
	assertNotNull(sample.getCatalog());
    }

    public void testTopicSet ()
    {
	assertEquals(sample.getTopicSetCount(), 2);
        assertEquals(sample.getTopicSet().length, 2);
	assertNotNull(sample.getTopicSet(0));
	assertNotNull(sample.getTopicSet(1));
	assertNull(sample.getTopicSet(2));
    }

    public void testNewsEnvelope ()
    {
	assertNotNull(sample.getNewsEnvelope());
    }

    public void testNewsItem ()
    {
	assertEquals(sample.getNewsItemCount(), 2);
        assertEquals(sample.getNewsItem().length, 2);
	assertNotNull(sample.getNewsItem(0));
	assertNotNull(sample.getNewsItem(1));
	assertNull(sample.getNewsItem(2));
    }

    public void testParent ()
    {
	assertNull(sample.getParent());
    }

    public void testChildren ()
    {
	assertEquals(sample.getChildCount(), 2);
        assertEquals(sample.getChild().length, 2);
	assertNotNull(sample.getChild(0));
	assertNotNull(sample.getChild(1));
	assertNull(sample.getChild(2));
	assertEquals(sample.getChild(0).getType(),
		     PrimaryNode.NEWS_ITEM);
	assertEquals(sample.getChild(1).getType(),
		     PrimaryNode.NEWS_ITEM);
    }

    public void testNewsMLCast ()
    {
	assertNotNull(sample.asNewsML());
    }

    protected PrimaryNode getPrimaryNode ()
    {
	return sample;
    }

    private NewsML sample;

}

// end of NewsMLTest.java
