// TopicTest.java - unit tests for Topic

package org.newsml.toolkit.dom.unittests;

import junit.framework.TestCase;

import org.newsml.toolkit.Topic;

public class TopicTest extends TestCase
{

    public TopicTest (String name)
    {
	super(name);
    }

    protected void setUp ()
	throws Exception
    {
	super.setUp();
	sample = SampleFactory.createNewsML().getTopicSet(1).getTopic(1);
    }

    public void testBase ()
    {
	assertEquals(sample.getXMLName(), "Topic");
	assertNotNull(sample.getSession());
    }

    public void testIdentifiers ()
    {
	assertEquals(sample.getDuid(), "topic01");
	assertEquals(sample.getEuid(), "id1");
    }

    public void testDetails ()
    {
	assertEquals(sample.getDetails(), "http://foo.com/details");
    }

    public void testComment ()
    {
	assertEquals(sample.getCommentCount(), 2);
        assertEquals(sample.getComment().length, 2);
	assertNotNull(sample.getComment(0));
	assertNotNull(sample.getComment(1));
	assertNull(sample.getComment(2));
    }

    public void testCatalog ()
    {
	assertNotNull(sample.getCatalog());
    }

    public void testTopicType ()
    {
	assertEquals(sample.getTopicTypeCount(), 2);
        assertEquals(sample.getTopicType().length, 2);
	assertNotNull(sample.getTopicType(0));
	assertNotNull(sample.getTopicType(1));
	assertNull(sample.getTopicType(2));
    }

    public void testFormalNameDecl ()
    {
	assertEquals(sample.getFormalNameDeclCount(), 2);
        assertEquals(sample.getFormalNameDecl().length, 2);
	assertNotNull(sample.getFormalNameDecl(0));
	assertNotNull(sample.getFormalNameDecl(1));
	assertNull(sample.getFormalNameDecl(2));
	assertEquals(sample.getFormalNameDecl(1).getScheme(), "scheme.a");
	assertEquals(sample.getFormalNameDecl(1).getName(), "name.b");
    }

    public void testDescription ()
    {
	assertEquals(sample.getDescriptionCount(), 2);
        assertEquals(sample.getDescription().length, 2);
	assertEquals(sample.getDescription(0).getValue(), "description.a");
	assertEquals(sample.getDescription(1).getValue(), "description.b");
	assertEquals(sample.getDescription(1).getVariant(), "variant");
	assertEquals(sample.getDescription(1).getLang(), "es");
	assertNull(sample.getDescription(2));
    }

    public void testProperty ()
    {
	assertEquals(sample.getPropertyCount(), 2);
        assertEquals(sample.getProperty().length, 2);
	assertNotNull(sample.getProperty(0));
	assertNotNull(sample.getProperty(1));
	assertNull(sample.getProperty(2));
    }

    private Topic sample;

}

// end of TopicTest.java
