// NewsMLTreeModel.java - map a NewsML node structure to a Swing tree.
// Copyright (c) 2000 by Reuters PLC and Wavo Company, Inc.
// $Id: NewsMLTreeModel.java,v 1.10 2001/05/23 01:56:19 david Exp $

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.newsml.toolkit.explorer;

import javax.swing.event.TreeModelListener;

import javax.swing.tree.TreeModel;
import javax.swing.tree.TreePath;

import org.newsml.toolkit.NewsML;
import org.newsml.toolkit.PrimaryNode;


/**
 * Map a NewsML node structure to a Swing tree.
 *
 * @author Reuters PLC
 * @version 1.0
 */
class NewsMLTreeModel implements TreeModel
{

    protected NewsMLTreeModel ()
    {
    }

    protected NewsMLTreeModel (NewsML root)
    {
	this.root = root;
    }

    public Object getRoot ()
    {
	return root;
    }

    public Object getChild (Object parent, int index)
    {
	PrimaryNode node = (PrimaryNode)parent;
	return node.getChild(index);
    }

    public int getChildCount (Object parent)
    {
	PrimaryNode node = (PrimaryNode)parent;
	int i = 0;
	while (node.getChild(i) != null)
	    i++;
	return i;
    }

    public boolean isLeaf (Object node)
    {
	return (((PrimaryNode)node).getChild(0) == null);
    }

    public void valueForPathChanged (TreePath path, Object newValue)
    {
	throw new IllegalStateException("NewsML tree may not be edited");
    }

    public int getIndexOfChild (Object parent, Object child)
    {
	int index = 0;
	Object node = getChild(parent, index);
	while (node != null) {
	    if (child.equals(node))
		return index;
	    index++;
	    node = getChild(parent, index);
	}
	return -1;
    }

    public void addTreeModelListener (TreeModelListener listener)
    {
	// TODO
    }

    public void removeTreeModelListener (TreeModelListener listener)
    {
	// TODO
    }

    private PrimaryNode root = null;

}

// end of NewsMLTreeModel.java
